@@ -419,6 +419,10 @@ my $configure_liferay=sub {
    my $server_host_block=$_[3]||'';
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my ($stdout,$stderr,$url)=(''.''.'');
+   ($stdout,$stderr)=$handle->cmd("sudo yum -y -v install java-1.8.0",
+      '__display__');
+   ($stdout,$stderr)=$handle->cmd("sudo yum -y -v remove java-1.7.0-openjdk",
+      '__display__');
    foreach my $k (1..5) {
       ($stdout,$stderr)=$handle->cmd("wget -qO- ".
          "http://sourceforge.net/projects/lportal/files/");
